# v0.3.4
- Fix version info after install

# v0.3.3
- Fix missing templates after install

# v0.3.2
- Add missing dependency

# v0.3.1
- Add yaml config support
- Clean up html page rendering

# v0.3.0
- Add trends

# v0.2.8
- Fix version status in pip analysis
- Add json report

# v0.2.7
- fix files

# v0.2.6
- Fully move namespace, fix script

# v0.2.5
- Change name of project to metripy

# v0.2.4
- Change name of project to py_codemetrics

# v0.2.3
- Fix test action by dropping 3.9, 3.10 support

# v0.2.2
- Fix test action

# v0.2.1
- Added git metrics json reporting
- Added some first tests
- Added github actions

# v0.2.0
- Added code analysis of typescript
- Added npm dependencies analysis

# v0.1.0
- Added main structure
- Added config loading and parsing
- Added code analysis of python
- Added code analysis of php
- Added git analysis
- Added composer dependencies analysis
- Added pip dependencies analysis
- Added html report dashboard, file insights, git insights, dependency insights
